@@ -16,7 +16,6 @@ from contextlib import contextmanager
 import logging
 import os
 from paramiko import SSHClient, SSHConfig, MissingHostKeyPolicy
-from paramiko.ssh_exception import SSHException, NoValidConnectionsError
 import shutil
 import signal
 import socket
@@ -29,20 +28,6 @@ from ducktape.utils.util import wait_until
 from ducktape.errors import DucktapeError
 
 
-def check_ssh(method):
-    def wrapper(self, *args, **kwargs):
-        try:
-            return method(self, *args, **kwargs)
-        except (SSHException, NoValidConnectionsError, socket.error) as e:
-            if self._custom_ssh_exception_checks:
-                self._log(logging.DEBUG, "starting ssh checks:")
-                self._log(logging.DEBUG, "\n".join(repr(f) for f in self._custom_ssh_exception_checks))
-                for func in self._custom_ssh_exception_checks:
-                    func(e, self)
-            raise
-    return wrapper
-
-
 class RemoteAccountSSHConfig(object):
     def __init__(self, host=None, hostname=None, user=None, port=None, password=None, identityfile=None, **kwargs):
         """Wrapper for ssh configs used by ducktape to connect to remote machines.
@@ -135,7 +120,7 @@ class RemoteAccount(HttpMixin):
     Each operating system has its own RemoteAccount implementation.
     """
 
-    def __init__(self, ssh_config, externally_routable_ip=None, logger=None, ssh_exception_checks=[]):
+    def __init__(self, ssh_config, externally_routable_ip=None, logger=None):
         # Instance of RemoteAccountSSHConfig - use this instead of a dict, because we need the entire object to
         # be hashable
         self.ssh_config = ssh_config
@@ -154,7 +139,6 @@ class RemoteAccount(HttpMixin):
         self.os = None
         self._ssh_client = None
         self._sftp_client = None
-        self._custom_ssh_exception_checks = ssh_exception_checks
 
     @property
     def operating_system(self):
@@ -175,7 +159,6 @@ class RemoteAccount(HttpMixin):
         msg = "%s: %s" % (str(self), msg)
         self.logger.log(level, msg, *args, **kwargs)
 
-    @check_ssh
     def _set_ssh_client(self):
         client = SSHClient()
         client.set_missing_host_key_policy(IgnoreMissingHostKeyPolicy())
@@ -267,7 +250,6 @@ class RemoteAccount(HttpMixin):
         except Exception:
             return False
 
-    @check_ssh
     def ssh(self, cmd, allow_fail=False):
         """Run the given command on the remote host, and block until the command has finished running.
 
@@ -301,7 +283,6 @@ class RemoteAccount(HttpMixin):
 
         return exit_status
 
-    @check_ssh
     def ssh_capture(self, cmd, allow_fail=False, callback=None, combine_stderr=True, timeout_sec=None):
         """Run the given command asynchronously via ssh, and return an SSHOutputIter object.
 
@@ -355,7 +336,6 @@ class RemoteAccount(HttpMixin):
 
         return SSHOutputIter(output_generator, stdout)
 
-    @check_ssh
     def ssh_output(self, cmd, allow_fail=False, combine_stderr=True, timeout_sec=None):
         """Runs the command via SSH and captures the output, returning it as a string.
 
@@ -407,7 +387,7 @@ class RemoteAccount(HttpMixin):
             return False
 
     def signal(self, pid, sig, allow_fail=False):
-        cmd = "kill -%s %s" % (str(sig), str(pid))
+        cmd = "kill -%d %s" % (int(sig), str(pid))
         self.ssh(cmd, allow_fail=allow_fail)
 
     def kill_process(self, process_grep_str, clean_shutdown=True, allow_fail=False):
@@ -507,7 +487,6 @@ class RemoteAccount(HttpMixin):
 
         return os.path.join(directory, path_basename)
 
-    @check_ssh
     def copy_from(self, src, dest):
         if os.path.isdir(dest):
             # dest is an existing directory, so assuming src looks like path/to/src_name,
@@ -534,7 +513,6 @@ class RemoteAccount(HttpMixin):
         warnings.warn("scp_to is now deprecated. Please use copy_to")
         self.copy_to(src, dest)
 
-    @check_ssh
     def copy_to(self, src, dest):
 
         if self.isdir(dest):
@@ -559,7 +537,6 @@ class RemoteAccount(HttpMixin):
                     # TODO what about uncopyable file types?
                     pass
 
-    @check_ssh
     def islink(self, path):
         try:
             # stat should follow symlinks
@@ -568,7 +545,6 @@ class RemoteAccount(HttpMixin):
         except Exception:
             return False
 
-    @check_ssh
     def isdir(self, path):
         try:
             # stat should follow symlinks
@@ -577,7 +553,6 @@ class RemoteAccount(HttpMixin):
         except Exception:
             return False
 
-    @check_ssh
     def exists(self, path):
         """Test that the path exists, but don't follow symlinks."""
         try:
@@ -587,7 +562,6 @@ class RemoteAccount(HttpMixin):
         except IOError:
             return False
 
-    @check_ssh
     def isfile(self, path):
         """Imitates semantics of os.path.isfile
 
@@ -604,7 +578,6 @@ class RemoteAccount(HttpMixin):
     def open(self, path, mode='r'):
         return self.sftp_client.open(path, mode)
 
-    @check_ssh
     def create_file(self, path, contents):
         """Create file at path, with the given contents.
 
@@ -612,14 +585,12 @@ class RemoteAccount(HttpMixin):
         """
         # TODO: what should semantics be if path exists? what actually happens if it already exists?
         # TODO: what happens if the base part of the path does not exist?
-
         with self.sftp_client.open(path, "w") as f:
             f.write(contents)
 
     _DEFAULT_PERMISSIONS = int('755', 8)
-
-    @check_ssh
     def mkdir(self, path, mode=_DEFAULT_PERMISSIONS):
+
         self.sftp_client.mkdir(path, mode)
 
     def mkdirs(self, path, mode=_DEFAULT_PERMISSIONS):
