@@ -22,8 +22,6 @@ from six import iteritems
 import sys
 import traceback
 
-import pysistence
-
 from ducktape.command_line.defaults import ConsoleDefaults
 from ducktape.command_line.parse_args import parse_args
 from ducktape.tests.loader import TestLoader, LoaderException
@@ -34,25 +32,7 @@ from ducktape.tests.runner import TestRunner
 from ducktape.tests.session import SessionContext, SessionLoggerMaker
 from ducktape.tests.session import generate_session_id, generate_results_dir
 from ducktape.utils.local_filesystem_utils import mkdir_p
-from ducktape.utils.util import load_function
-
-
-def extend_import_paths(paths):
-    """Extends sys.path with top-level packages found based on a set of input paths. This only adds top-level packages
-    in order to avoid naming conflict with internal packages, e.g. ensure that a package foo.bar.os does not conflict
-    with the top-level os package.
-
-    Adding these import paths is necessary to make importing tests work even when the test modules are not available on
-    PYTHONPATH/sys.path, as they normally will be since tests generally will not be installed and available for import
-
-    :param paths:
-    :return:
-    """
-    for path in paths:
-        dir = os.path.abspath(path if os.path.isdir(path) else os.path.dirname(path))
-        while os.path.exists(os.path.join(dir, '__init__.py')):
-            dir = os.path.dirname(dir)
-        sys.path.append(dir)
+from ducktape.utils import persistence
 
 
 def get_user_defined_globals(globals_str):
@@ -64,7 +44,7 @@ def get_user_defined_globals(globals_str):
     :return dict containing user-defined global variables
     """
     if globals_str is None:
-        return pysistence.make_dict()
+        return persistence.make_dict()
 
     from_file = False
     if os.path.isfile(globals_str):
@@ -93,9 +73,8 @@ def get_user_defined_globals(globals_str):
 
         raise ValueError(message)
 
-    # Use pysistence to create the immutable dict
-    user_globals = pysistence.make_dict(**user_globals)
-    return user_globals
+    # create the immutable dict
+    return persistence.make_dict(**user_globals)
 
 
 def setup_results_directory(new_results_dir):
@@ -150,11 +129,10 @@ def main():
         session_logger.debug("Configuration: %s=%s", k, v)
 
     # Discover and load tests to be run
-    extend_import_paths(args_dict["test_path"])
     loader = TestLoader(session_context, session_logger, repeat=args_dict["repeat"], injected_args=injected_args,
                         subset=args_dict["subset"], subsets=args_dict["subsets"])
     try:
-        tests = loader.load(args_dict["test_path"])
+        tests = loader.load(args_dict["test_path"], excluded_test_symbols=args_dict['exclude'])
     except LoaderException as e:
         print("Failed while trying to discover tests: {}".format(e))
         sys.exit(1)
@@ -182,14 +160,7 @@ def main():
         (cluster_mod_name, cluster_class_name) = args_dict["cluster"].rsplit('.', 1)
         cluster_mod = importlib.import_module(cluster_mod_name)
         cluster_class = getattr(cluster_mod, cluster_class_name)
-
-        cluster_kwargs = {"cluster_file": args_dict["cluster_file"]}
-        checker_function_names = args_dict['ssh_checker_function']
-        if checker_function_names:
-            checkers = [load_function(func_path) for func_path in checker_function_names]
-            if checkers:
-                cluster_kwargs['ssh_exception_checks'] = checkers
-        cluster = cluster_class(**cluster_kwargs)
+        cluster = cluster_class(cluster_file=args_dict["cluster_file"])
         for ctx in tests:
             # Note that we're attaching a reference to cluster
             # only after test context objects have been instantiated
@@ -200,11 +171,7 @@ def main():
         sys.exit(1)
 
     # Run the tests
-    deflake_num = args_dict['deflake']
-    if deflake_num < 1:
-        session_logger.warning("specified number of deflake runs specified to be less than 1, running without deflake.")
-    deflake_num = max(1, deflake_num)
-    runner = TestRunner(cluster, session_context, session_logger, tests, deflake_num)
+    runner = TestRunner(cluster, session_context, session_logger, tests)
     test_results = runner.run_all_tests()
 
     # Report results
