@@ -294,6 +294,7 @@ class TestContext(object):
         self.session_context = kwargs.get("session_context")
         self.cluster = kwargs.get("cluster")
         self.module = kwargs.get("module")
+        self.test_suite_name = kwargs.get("test_suite_name")
 
         if kwargs.get("file") is not None:
             self.file = os.path.abspath(kwargs.get("file"))
@@ -344,8 +345,8 @@ class TestContext(object):
         return {
             "directory": os.path.dirname(self.file),
             "file_name": os.path.basename(self.file),
-            "cls_name": self.cls_name,
-            "method_name": self.function_name,
+            "cls_name": self.cls.__name__,
+            "method_name": self.function.__name__,
             "injected_args": self.injected_args
         }
 
