@@ -27,6 +27,8 @@ from threading import Thread
 import time
 import logging
 
+from ducktape.utils.util import wait_until
+
 
 def generate_tempdir_name():
     """Use this ad-hoc function instead of the tempfile module since we're creating and removing
@@ -87,27 +89,6 @@ class GenericService(Service):
         node.account.remove(self.worker_scratch_dir, allow_fail=True)
 
 
-class UnderUtilizedTest(Test):
-
-    def setup(self):
-        self.service = GenericService(self.test_context, 1)
-
-    @cluster(num_nodes=3)
-    def under_utilized_test(self):
-        # setup() creates a service instance, which calls alloc() for one node
-        assert self.test_context.cluster.max_used() == 1
-        assert len(self.test_context.cluster.used()) == 1
-
-        self.another_service = GenericService(self.test_context, 1)
-        assert len(self.test_context.cluster.used()) == 2
-        assert self.test_context.cluster.max_used() == 2
-
-        self.service.stop()
-        self.service.free()
-        assert len(self.test_context.cluster.used()) == 1
-        assert self.test_context.cluster.max_used() == 2
-
-
 class FileSystemTest(Test):
     """
     Note that in an attempt to isolate the file system methods, validation should be done with ssh/shell commands.
@@ -427,10 +408,6 @@ class RemoteAccountTest(Test):
     def setup(self):
         self.account_service.start()
 
-    @cluster(num_nodes=1)
-    def test_flaky(self):
-        assert random.choice([True, False, False])
-
     @cluster(num_nodes=1)
     def test_ssh_capture_combine_stderr(self):
         """Test that ssh_capture correctly captures stderr and stdout from remote process.
@@ -534,6 +511,29 @@ class RemoteAccountTest(Test):
             end = time.time()
             assert end - start > timeout, "Should have waited full timeout period while monitoring the log"
 
+    @cluster(num_nodes=1)
+    def test_kill_process(self):
+        """Tests that kill_process correctly works"""
+
+        def get_pids():
+            pid_cmd = "ps ax | grep -i nc | grep -v grep | awk '{print $1}'"
+
+            return list(node.account.ssh_capture(pid_cmd, callback=int))
+
+        node = self.account_service.nodes[0]
+
+        # Run TCP service using netcat
+        node.account.ssh_capture("nohup nc -l -p 5000 > /dev/null 2>&1 &")
+
+        wait_until(lambda: len(get_pids()) > 0, timeout_sec=10,
+                   err_msg="Failed to start process within %d sec" % 10)
+
+        # Kill service.
+        node.account.kill_process("nc")
+
+        wait_until(lambda: len(get_pids()) == 0, timeout_sec=10,
+                   err_msg="Failed to kill process within %d sec" % 10)
+
 
 class TestIterWrapper(Test):
     def setup(self):
